@@ -13,15 +13,6 @@
 from enum import Enum
 
 
-class SourceType(Enum):
-    MYSQL = "MYSQL"
-    POSTGRESQL = "POSTGRESQL"
-    REDSHIFT = "REDSHIFT"
-    SNOWFLAKE = "SNOWFLAKE"
-    KAFKA = "KAFKA"
-    REST = "REST"
-
-
 class DatasetType(Enum):
     DB_TABLE = "DB_TABLE"
     STREAM = "STREAM"
